about summary refs log tree commit diff
path: root/elf/dl-support.c
diff options
context:
space:
mode:
authorUlrich Drepper <drepper@redhat.com>2003-05-04 04:30:13 +0000
committerUlrich Drepper <drepper@redhat.com>2003-05-04 04:30:13 +0000
commitf866314b89d56845f55e6f365e18b31ec978ec3a (patch)
tree24177a21031b2cc13c60cbf6901c9b652dc2ea99 /elf/dl-support.c
parent003f9e7223a13d1c482424deb294647d35dbec92 (diff)
downloadglibc-f866314b89d56845f55e6f365e18b31ec978ec3a.tar.gz
glibc-f866314b89d56845f55e6f365e18b31ec978ec3a.tar.xz
glibc-f866314b89d56845f55e6f365e18b31ec978ec3a.zip
Update.
2003-04-22  Roland McGrath  <roland@redhat.com>

	* elf/elf.h (AT_SYSINFO_EHDR): New macro, replaces AT_SYSINFO_EH_FRAME.
	* sysdeps/generic/ldsodefs.h (struct rtld_global): Remove
	dl_sysinfo_eh_frame member, add dl_sysinfo_dso member instead.
	* elf/dl-support.c: Update defn.
	* sysdeps/generic/libc-start.c: Don't call __register_frame_info_bases.
	* sysdeps/generic/dl-sysdep.c (_dl_sysdep_start) [NEED_DL_SYSINFO]:
	Set GL(dl_sysinfo_dso) from AT_SYSINFO_EHDR.
	(_dl_show_auxv): Grok AT_SYSINFO_EHDR, not AT_SYSINFO_EH_FRAME.
	* elf/rtld.c (dl_main) [NEED_DL_SYSINFO]: If GL(dl_sysinfo_dso) is
	set, set up a link_map for the preloaded, prelinked object.
Diffstat (limited to 'elf/dl-support.c')
-rw-r--r--elf/dl-support.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/elf/dl-support.c b/elf/dl-support.c
index 1e547d3b4d..2ff3d2f905 100644
--- a/elf/dl-support.c
+++ b/elf/dl-support.c
@@ -127,8 +127,8 @@ size_t _dl_phnum;
 #ifdef NEED_DL_SYSINFO
 /* Needed for improved syscall handling on at least x86/Linux.  */
 uintptr_t _dl_sysinfo = DL_SYSINFO_DEFAULT;
-/* Address of the unwind info for the vsyscall page.  */
-uintptr_t _dl_sysinfo_eh_frame;
+/* Address of the ELF headers in the vsyscall page.  */
+const ElfW(Ehdr) *_dl_sysinfo_dso;
 #endif
 
 /* During the program run we must not modify the global data of